<?php
include( dirname( dirname( __FILE__ ) ) . '/../lib/afp/admin-page-framework.php' );

if ( ! class_exists( 'fasterImage_AdminPageFramework' ) ) {
    return;
}


class fasterImagePlugin extends fasterImage_AdminPageFramework {

    public function setUp() {

        // Create the root menu
        $this->setRootMenuPage('Settings');

        // Add the sub menu item
        $this->addSubMenuItems(
            array(
                'title' => 'fasterImage',        // page title
                'page_slug' => 'fasterimage_settings'
            )
        );

        $this->addInPageTabs(
            'fasterimage_settings',
            array(
                'tab_slug' => 'fi_tab_dashboard',
                'title' => 'Tableau de Bord'
            ),
            array(
                'tab_slug' => 'fi_tab_settings',
                'title' => 'Paramètres'
            )
        );

        $this->setPageHeadingTabsVisibility( false );
        $this->setInPageTabTag( 'h2' );
        $this->setPageTitleVisibility( false );

        $this->enqueueStyle(
            plugins_url('fasterimage/src/css/admin.css','','',array('version' => FASTERIMAGE_VERSION))
        );

        $this->enqueueScript(
            plugins_url('fasterimage/src/js/admin.js','','',array('version' => FASTERIMAGE_VERSION))
        );

    }

    /* ***** FORMS ******* */

    public function validation_fasterImagePlugin($aInput, $aOldInput) {

        $bOk = true;

        $aErrors = array();

        if(isset($aInput['fasterimage_api_key'])) {
            $aInput['fasterimage_api_key'] = strtolower($aInput['fasterimage_api_key']);

            if(strlen($aInput['fasterimage_api_key']) == 0) {
                $aInput['fasterimage_enabled'] = "0";
                update_option('fasterimage_enabled', '0');
            }
            elseif($aOldInput['fasterimage_api_key'] != $aInput['fasterimage_api_key']) {
                $aData = fasterimage_api_getinfo($aInput['fasterimage_api_key']);
                if($aData === false || !is_array($aData)) {
                    $bOk = false;
                    $aErrors['fasterimage_api_key'] = 'Une erreur de connexion s\'est produite lors de l\'appel à l\'API. Veuillez recommencer ou contacter le support.';

                    $aInput['fasterimage_enabled'] = "0";
                    update_option('fasterimage_enabled', '0');
                }
                else {
                    if ($aData['status'] == "KO") {
                        $bOk = false;
                        $aErrors['fasterimage_api_key'] = 'Cette clé API ne semble pas valide. Veuillez vérifier votre saisie ou contacter le support si le problème persiste.';

                        $aOldInput['fasterimage_enabled'] = "0";
                        $aInput['fasterimage_enabled'] = "0";
                        update_option('fasterimage_enabled', '0');
                    } else {
                        update_option('fasterimage_account_valid', '1');
                        update_option('fasterimage_enabled', '1');
                        update_option('fasterimage_account_valid_expiration', time());
                        update_option('fasterimage_domain',$aData['domain']);

                        $aInput['fasterimage_enabled'] = "1";
                    }
                }
            }
            else {

                $aData = fasterimage_api_getinfo($aInput['fasterimage_api_key']);
                if($aData === false || !is_array($aData) || $aData['status'] == "KO")  {
                    $bOk = false;
                    $aErrors['fasterimage_api_key'] = 'Cette clé API ne semble pas valide. Veuillez vérifier votre saisie ou contacter le support si le problème persiste.';

                    $aInput['fasterimage_enabled'] = "0";
                    $aOldInput['fasterimage_enabled'] = "0";
                    update_option('fasterimage_enabled', '0');
                }
                else {
                    if($aInput['fasterimage_enabled'] == "0") {
                        update_option('fasterimage_enabled', '0');
                    }
                    else {
                        update_option('fasterimage_enabled', '1');
                    }
                }


            }
            /*if($aInput['fasterimage_api_key'] == "") {
                $bOk = false;
                $aErrors['fasterimage_api_key'] = 'Cette clé n\'est pas valide';
            }*/
        }

        if(!$bOk) {
            $this->setFieldErrors( $aErrors );
            $this->setSettingNotice( 'Une erreur s\'est produite, veuillez vérifier votre saisie et recommencer.' );
            return $aOldInput;
        }

        return $aInput;

    }

    /* ***** HEADER ****** */

    public function content_top_fasterImagePlugin($sContent) {

        $aNotices =  get_option('fasterimage_admin_notices', array());
        foreach ($aNotices as $key => $value) {
            if ("install" === $value) {
                unset($aNotices[$key]);
            }
        }
        update_option('fasterimage_admin_notices', $aNotices);

        $sTitle = '<div class="header"><a href="http://fasterimage.io/?utm_source=wordpress&utm_medium=plugin&utm_campaign=header" target="_blank"><img src="http://fasterimage.io.fasterimage.io/img/logo.png" /></a>
                <h1>Optimisez vos images & Accélérez votre site Web !</h1>
                <em>Plugin WordPress - version '.FASTERIMAGE_VERSION.'</em>
                <div class="aide">
                <a href="https://twitter.com/fasterimage" class="twitter-follow-button" data-show-count="false">Suivre @fasterimage</a>';

        $sTitle .= "<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src=p+'://platform.twitter.com/widgets.js';fjs.parentNode.insertBefore(js,fjs);}}(document, 'script', 'twitter-wjs');</script>";

        $sTitle .= '<br/><a class="link-subscribe" href="http://fasterimage.io/contact?utm_source=wordpress&utm_medium=plugin&utm_campaign=footer" target="_blank">Aide / Support</a><br/><a class="link-subscribe" href="mailto:contact@fasterimage.io" target="_blank">contact@fasterimage.io</a>';
        $sTitle .= '</div>';

        $sTitle .= '</div>';

        return $sTitle.$sContent;
    }

    /*public function content_fasterimage_settings( $sContent) {
        return $sContent. ' <h3>ccc</h3><p>ccc</p>';
    }*/

    /* ****** DASHBOARD ******* */

    public function content_fasterimage_settings_fi_tab_dashboard( $sContent) {
        $sApiKey = fasterImagePlugin::getOption('fasterImagePlugin','fasterimage_api_key');

        if(!isset($_GET['tab']) || $_GET['tab'] != 'fi_tab_dashboard') {
            return "<div class=\"text-center\"><br/>Chargement de l'interface en cours ...</div><script>document.location.href = '".get_site_url()."/wp-admin/options-general.php?page=fasterimage_settings&tab=fi_tab_dashboard'; </script>";
        }
        else {
            if($sApiKey === null || $sApiKey == '') {
                $sHtml = '<h3 class="text-center">Merci d\'avoir téléchargé et installé le plugin fasterImage !</h3>';

                $sHtml .= '<table class="login">';
                $sHtml .= '<tr><td class="text-center border-right"><strong>Vous n\'avez pas encore de compte ?</strong><a class="link-subscribe" href="http://fasterimage.io/?utm_source=wordpress&utm_medium=plugin&utm_campaign=settings" target="_blank">Créez un compte gratuitement</a>';
                $sHtml .= ' pour optimiser vos images et utilisez <pre>' . str_replace(array('http://', 'https://'), '', get_site_url()) . '</pre> comme nom de domaine lors de la configuration.  </td>';
                $sHtml .= '<td class="text-center"><strong>Vous avez déjà un compte,</strong>indiquez la clé API fournie pour votre nom de domaine : <div id="api_key_form"></div></td></tr>';
                $sHtml .= '</table>';
            }
            else {

                $aData = fasterimage_api_getinfo();

                /*if($aData === false || !is_array($aData)) {
                    echo "Erreur de connexion";
                }
                else {*/
                if($aData['status'] == "KO") {


                    $sHtml = '<table class="login">';
                    $sHtml .= '<tr><td class="text-center"><strong>Clé API invalide</strong> Il semblerait que votre clé API ait été mise à jour ou n\'est plus valide.';
                    $sHtml .= 'Veuillez vérifier la clé API dans les <a href="'.get_site_url().'/wp-admin/options-general.php?page=fasterimage_settings&tab=fi_tab_settings">paramètres de fasterImage</a>';
                    $sHtml .= '</td></tr></table>';

                }
                else {
                    update_option('fasterimage_account_valid', '1');
                    update_option('fasterimage_account_valid_expiration', time());

                    $sHtml = '<table class="dashboard"><tr>';

                    $sEnabled = get_option('fasterimage_enabled');
                    $sDomain = get_option('fasterimage_domain');
                    $sChecked = get_option('fasterimage_account_valid');

                    $sFileOk = ($sEnabled == '1' && strlen($sDomain) > 0 && $sChecked == '1') ? 'ok' : 'ko';

                    $sHtml .= '<td><img src="'.plugins_url('fasterimage/src/img/'.$sFileOk.'.png').'" /><strong>Optimisation '.($sEnabled == '1' && strlen($sDomain) > 0 && $sChecked == '1' ? 'activée' : 'désactivée').'</strong><a href="'.get_site_url().'/wp-admin/options-general.php?page=fasterimage_settings&tab=fi_tab_settings">Paramètres</a></td>';

                    $sHtml .= '<td><b>'.$aData['nb_images'].'</b><strong>Images optimisées</strong><a href="https://fasterimage.io/compte?utm_source=wordpress&utm_medium=plugin&utm_campaign=settings" target="_blank">Plus de stats</a></td>';

                    $iBP = $aData['bp_economisee'];

                    $sFact = "";
                    if($iBP > 0) {
                        switch (rand(0, 2)) {
                            case 0:
                                $iNbSecondes3G = $iBP / 93750;
                                $secondes = floor((($iNbSecondes3G % 86400) % 3600) % 60);
                                $minutes = floor((($iNbSecondes3G % 86400) % 3600) / 60);
                                $hours = floor(($iNbSecondes3G % 86400) / 3600);
                                $days = floor($iNbSecondes3G / 86400);
                                $sDuree3G = ($days > 0 ? $days . ' jour' . ($days > 1 ? 's' : '') . ', ' : '') . ($hours > 0 ? $hours . ' heure' . ($hours > 1 ? 's' : '') . ' ' : '') . ($minutes > 0 ? $minutes . ' minute' . ($minutes > 1 ? 's' : '') . ' et ' : '') . $secondes . ' secondes';
                                $sFact = 'C\'est ' . $sDuree3G . ' de téléchargement en 3G!';
                                break;
                            case 1:
                                $iNbDisquettes = round($iBP / 1440000);
                                $sFact = "C'est " . $iNbDisquettes . " disquette" . ($iNbDisquettes > 1 ? 's' : '') . " 3,5\"!";
                                break;
                            case 2:
                                if($iBP < 7500000000 ) {
                                    $iRatioWikipedia = $iBP / 7500000000 * 100;
                                    $iRatioWikipedia = round($iRatioWikipedia);
                                    $sFact = "C'est ".$iRatioWikipedia."% du volume de Wikipedia en Français!";
                                }
                                else {
                                    $iRatioWikipedia = $iBP / 7500000000;
                                    $iRatioWikipedia = round($iRatioWikipedia,2);
                                    $sFact = "C'est ".str_replace('.',',',$iRatioWikipedia)." fois le volume de Wikipedia en Français!";
                                }


                                break;
                        }
                    }


                    $sHtml .= '<td><b>'.formatOctets($aData['bp_economisee']).'</b><strong>Bande passante économisée</strong><span>'.$sFact.'</span></td>';

                    $sHtml .= '<td><strong><b>'.formatOctets($aData['quota_utilisation']).'</b>/ '.formatOctets($aData['quota_max']).'</strong><strong>Quota utilisé</strong><a href="http://fasterimage.io/compte/plans?utm_source=wordpress&utm_medium=plugin&utm_campaign=settings" target="_blank">Augmenter cette limite</a></td>';

                    $sHtml .= '</tr></table>';

                    $sDomain = get_option('fasterimage_domain');
                    $sHtml .= '<div class="text-center info-html">';
                    $sHtml .= '<em>Les images de votre site gérées par WordPress sont automatiquement optimisées.</em><br/><br/>';
                    $sHtml .= 'Si vous souhaitez ajouter une image manuellement (dans votre thème par exemple) vous pouvez utiliser cette syntaxe :';
                    $sHtml .= '<pre>&lt;img src="<strong>http://'.$sDomain.'.fasterimage.io/dossier/image.png</strong>" alt="Mon image optimisée" /></pre>';
                    $sHtml .= 'ou dans un fichier CSS :';
                    $sHtml .= '<pre>background-image:url(<strong>http://'.$sDomain.'.fasterimage.io/dossier/image.png</strong>);</pre>';
                    $sHtml .= '(Pensez à changer <pre style="display:inline;">http://</pre> en <pre style="display:inline;">https://</pre> si vous êtes en mode sécurisé)';
                    $sHtml .= '</div>';

                }
                //}
            }

            return $sHtml.$sContent;
        }
    }

    public function load_fasterimage_settings_fi_tab_dashboard( $oAdminPage) {
        $sApiKey = fasterImagePlugin::getOption('fasterImagePlugin','fasterimage_api_key');

        if($sApiKey === null || $sApiKey == '') {
            $this->addSettingFields(
                array(    // Single text field
                    'field_id' => 'fasterimage_api_key',
                    'type' => 'text',
                    'title' => 'Clé API',
                    'description' => 'Votre clé se trouve dans :<br/><a href="https://fasterimage.io/compte/domaines" target="_blank">\'Mon Compte\' &raquo; \'Noms de domaine\'</a> ',
                ),
                array( // Submit button
                    'field_id' => 'submit_button',
                    'type' => 'submit',
                )
            );
        }

    }

    /* ******* SETTINGS ******** */

    public function content_fasterimage_settings_fi_tab_settings( $sContent) {

        $sHtml = "";

        /*$sDomain = get_option('fasterimage_domain');
        if(strlen($sDomain) > 0) {
            $sHtml .= "";
        }*/

        if(FASTERIMAGE_DEBUG) {

            $sValid = get_option('fasterimage_account_valid');
            $sValidTime = get_option('fasterimage_account_valid_expiration');
            $sDomain = get_option('fasterimage_domain');
            $sEnabled = get_option('fasterimage_enabled');

            $sHtml .= "<h3>DEBUG :</h3>";
            $sHtml .= "<br/>Valid : ".$sValid;
            $sHtml .= "<br/>Valid time : ".$sValidTime;
            $sHtml .= "<br/>Domain : ".$sDomain;
            $sHtml .= "<br/>Enabled : ".$sEnabled;
            if(get_option('fasterImagePlugin') !== false) {
                $sHtml .= "<br/>Plugin options : ".print_r(get_option('fasterImagePlugin'),true);
            }
            else {
                $sHtml .= "<br/>Plugin options : -";
            }

        }

        return $sContent. $sHtml;
    }

    public function load_fasterimage_settings_fi_tab_settings( $oAdminPage) {
        $this->addSettingFields(
            array(    // Single text field
                'field_id' => 'fasterimage_enabled',
                'type' => 'checkbox',
                'title' => 'Activer le plugin',
                'description' => 'Cochez cette case pour activer l\'optimisation des images.'
            ),
            array(    // Single text field
                'field_id' => 'fasterimage_api_key',
                'type' => 'text',
                'title' => 'Clé API',
                'description' => 'Disponible dans :<br/><a href="https://fasterimage.io/compte/domaines" target="_blank">\'Mon Compte\' &raquo; \'Noms de domaine\'</a> ',
            ),
            array( // Submit button
                'field_id' => 'submit_button',
                'type' => 'submit',
                'value' => 'Enregistrer'
            )
        );

    }
}